@@ -130,7 +130,7 @@ class mintConfigWindow:
 	self.add_button("hbuttonbox8","/usr/share/applications/palimpsest.desktop",True,"")         	
 	self.add_button("hbuttonbox7","/usr/share/applications/ndisgtk.desktop",True,"")
         self.add_button("hbuttonbox8","/usr/share/applications/jockey-gtk.desktop",True,"")        
-        self.add_button("hbuttonbox7","/usr/share/applications/chestnut-dialer-gtk2.desktop",True,"")	
+        self.add_button("hbuttonbox7","/usr/share/applications/gnome-ppp.desktop",True,"")	
 
         self.add_button("hbuttonbox10","/usr/share/applications/xfce-display-settings.desktop",True,"")
 	self.add_button("hbuttonbox10","/usr/share/applications/xfce-keyboard-settings.desktop",True,"")
@@ -140,8 +140,8 @@ class mintConfigWindow:
         self.add_button("hbuttonbox12","/usr/share/applications/xfce4-mixer.desktop",True,"")
         self.add_button("hbuttonbox11","/usr/share/applications/thunar-volman-settings.desktop",True,"")
         self.add_button("hbuttonbox12","/usr/share/applications/bluetooth-properties.desktop",True,"")
+	self.add_button("hbuttonbox10","/usr/share/applications/simple-scan.desktop",True,"")
         self.add_button("hbuttonbox10","/usr/share/applications/scim-setup.desktop",True,"")
-	self.add_button("hbuttonbox10","/usr/share/applications/flegita.desktop",True,"")
 	self.add_button("hbuttonbox12","/usr/share/applications/nvidia-settings.desktop",True,"")
 
         self.add_button("hbuttonbox13","/usr/share/applications/nm-connection-editor.desktop",True,"") 
@@ -160,10 +160,7 @@ class mintConfigWindow:
 	self.add_button("hbuttonbox17","/usr/share/applications/exo-preferred-applications.desktop",True,"")
         self.add_button("hbuttonbox18","/usr/share/applications/xfce-session-settings.desktop",True,"")
         self.add_button("hbuttonbox18","/usr/share/applications/gnome-system-monitor.desktop",True,"")
-        self.add_button("hbuttonbox17","/usr/share/applications/gconf-editor.desktop",True,"")
-	self.add_button("hbuttonbox18","/usr/share/applications/seahorse-pgp-preferences.desktop",True,"")
         self.add_button("hbuttonbox16","/usr/share/applications/language-selector.desktop",True,"")
-	self.add_button("hbuttonbox17","/usr/share/applications/polkit-gnome-authorization.desktop",True,"")	
         self.add_button("hbuttonbox16","/usr/share/applications/time.desktop",True,"")
 	self.add_button("hbuttonbox16","/usr/share/applications/synaptic-mintconfig.desktop",True,"")
 	self.add_button("hbuttonbox18","/usr/share/applications/mintUpdate.desktop",True,"")
@@ -171,17 +168,20 @@ class mintConfigWindow:
         self.add_button("hbuttonbox16","/usr/share/applications/mintInstall.desktop",True,"")
         self.add_button("hbuttonbox17","/usr/share/applications/mintBackup.desktop",True,"")
         self.add_button("hbuttonbox18","/usr/share/applications/mintwelcome.desktop",True,"")
-        self.add_button("hbuttonbox16","/usr/share/applications/file-uploader.desktop",True,"")
+        self.add_button("hbuttonbox17","/usr/share/applications/file-uploader.desktop",True,"")
+        self.add_button("hbuttonbox16","/usr/share/applications/gconf-editor.desktop",True,"")
+	self.add_button("hbuttonbox17","/usr/share/applications/seahorse-pgp-preferences.desktop",True,"")
         
 	self.add_button("vbuttonbox5","/usr/share/applications/xfce-backdrop-settings.desktop",True,"")
 	self.add_button("vbuttonbox5","/usr/share/applications/xfce-ui-settings.desktop",True,"")
         self.add_button("vbuttonbox6","/usr/share/applications/xfce-wm-settings.desktop",True,"")	
 	self.add_button("vbuttonbox7","/usr/share/applications/xfce-wmtweaks-settings.desktop",True,"")
         self.add_button("vbuttonbox7","/usr/share/applications/xfce-workspaces-settings.desktop",True,"")
-        self.add_button("vbuttonbox5","/usr/share/applications/gdmsetup.desktop",True,"")
-	self.add_button("vbuttonbox6","/usr/share/applications/xfcemintDesktop.desktop",True,"")
+        self.add_button("vbuttonbox6","/usr/share/applications/gdmsetup.desktop",True,"")
+	self.add_button("vbuttonbox5","/usr/share/applications/xfcemintDesktop.desktop",True,"")
+	self.add_button("vbuttonbox6","/usr/share/applications/ccsm.desktop",True,"")	  
         self.add_button("vbuttonbox7","/usr/share/applications/emerald-theme-manager.desktop",True,"")
-	self.add_button("vbuttonbox5","/usr/share/applications/ccsm.desktop",True,"")	      
+    
 
 	
         custom_list1 = client.get_list("/apps/xfcemintConfig/custom_list1",gconf.VALUE_STRING)
